@@ -28,7 +28,7 @@ def initialize_server_request(request):
 def send_oauth_error(err=None):
     """Shortcut for sending an error."""
     # send a 401 error
-    response = HttpResponse(err.message.encode('utf-8'), mimetype="text/plain")
+    response = HttpResponse(err.message.encode('utf-8'), content_type="text/plain")
     response.status_code = 401
     # return the authenticate header
     header = oauth.build_authenticate_header(realm=OAUTH_REALM_KEY_NAME)
@@ -47,12 +47,12 @@ def get_oauth_request(request):
         auth_header =  {'Authorization': request.META['HTTP_AUTHORIZATION']}
 
 
-    # Don't include extra parameters when request.method is POST and
-    # request.META['CONTENT_TYPE'] is "application/x-www-form-urlencoded"
-    # (See http://oauth.net/core/1.0a/#consumer_req_param).
+    # include POST parameters if content type is
+    # 'application/x-www-form-urlencoded' and request
+    # see: http://tools.ietf.org/html/rfc5849#section-3.4.1.3.1
     parameters = {}
 
-    if not auth_header and request.method == "POST" and (request.META.get('CONTENT_TYPE') == "application/x-www-form-urlencoded"):
+    if request.method == "POST" and request.META.get('CONTENT_TYPE') == "application/x-www-form-urlencoded":
         parameters = dict((k, v.encode('utf-8')) for (k, v) in request.POST.iteritems())
 
     absolute_uri = request.build_absolute_uri(request.path)
